@@ -1,3 +1,4 @@
+{-# LANGUAGE OverloadedStrings #-}
 module Main where
 
 import Control.Exception
@@ -14,18 +15,18 @@ file :: String
 file = "hello"
 
 write :: String -> IO ()
-write path = do
+write path =
     writeFile (path ++ '/':file) ""
 
 modify :: String -> IO ()
-modify path = do
+modify path =
     bracket
         (openFile (path ++ '/':file) AppendMode)
-        (hClose)
+        hClose
         (\h -> hPutStr h "yarr!")
 
 remove :: String -> IO ()
-remove path = do
+remove path =
     removeFile (path ++ '/':file)
 
 action :: String -> IO ()
@@ -44,12 +45,12 @@ main =
 
 expected :: [Event]
 expected =
-    [ Created   False file
-    , Opened    False (Just file)
-    , Modified  False (Just file)
-    , Closed    False (Just file) True
-    , Opened    False (Just file)
-    , Modified  False (Just file)
-    , Closed    False (Just file) True
-    , Deleted   False file
+    [ Created   False "hello"
+    , Opened    False (Just "hello")
+    , Modified  False (Just "hello")
+    , Closed    False (Just "hello") True
+    , Opened    False (Just "hello")
+    , Modified  False (Just "hello")
+    , Closed    False (Just "hello") True
+    , Deleted   False "hello"
     ]
